@@ -4,49 +4,6 @@ use warnings;
 use base qw/App::CLI::Command/;
 use File::Find qw(find);
 use Locale::Maketext::Simple;
-use Pod::Simple::Text;
-
-our $VERSION = '0.4.2';
-
-=head1 NAME
-
-App::CLI::Command::Help
-
-=head1 SYNOPSIS
-
-    package MyApp::Help;
-    use base qw(App::CLI::Command::Help);
-
-    sub run {
-        my ($self, @args) = @_;
-        # preprocess
-        $self->SUPER(@_);       # App::CLI::Command::Help would output POD of each command
-    }
-
-=head1 DESCRIPTION
-
-Your command class should be capitalized.
-
-To add help message, just add POD in the command class:
-
-    package YourApp::Command::Foo;
-
-
-    =head1 NAME
-
-    YourApp::Command::Foo - execute foo
-
-    =head1 DESCRIPTION
-
-    blah blah
-
-    =head1 USAGE
-
-    ....
-
-    =cut
-
-=cut
 
 sub run {
     my $self = shift;
@@ -63,13 +20,12 @@ sub run {
         }
         elsif (my $file = $self->_find_topic($topic)) {
             open my $fh, '<:utf8', $file or die $!;
-            require Pod::Simple::Text;
             my $parser = Pod::Simple::Text->new;
             my $buf;
             $parser->output_string(\$buf);
             $parser->parse_file($fh);
 
-            $buf =~ s/^NAME\s+(.*?)::Help::\S+ - (.+)\s+DESCRIPTION/    $2:/;
+            $buf =~ s/^NAME\s+(.*?)::Help::\S+ - (.+)\s+DESCRIPTION/    $1:/;
             print $self->loc_text($buf);
         }
         else {
@@ -81,7 +37,7 @@ sub run {
 
 sub help_base {
     my $self = shift;
-    return $self->app."::Help";
+    return ref($self->app)."::Help";
 }
 
 my ($inc, @prefix);
